@@ -109,7 +109,7 @@ async fn actual_main(cli_app: Ferium) -> Result<()> {
         } => {
             check_internet().await?;
             add::modrinth(
-                &modrinth,
+                modrinth,
                 &project_id,
                 profile,
                 Some(!dont_check_game_version),
@@ -124,15 +124,13 @@ async fn actual_main(cli_app: Ferium) -> Result<()> {
             dont_check_mod_loader,
         } => {
             check_internet().await?;
-            eprint!("Adding mod... ");
-            let repo = libium::add::github(
+            add::github(
                 github.repos(owner, name),
                 profile,
                 Some(!dont_check_game_version),
                 Some(!dont_check_mod_loader),
             )
             .await?;
-            println!("{} ({})", *TICK, repo.name);
         },
         SubCommands::AddCurseforge {
             project_id,
@@ -141,7 +139,7 @@ async fn actual_main(cli_app: Ferium) -> Result<()> {
         } => {
             check_internet().await?;
             add::curseforge(
-                &curseforge,
+                curseforge,
                 project_id,
                 profile,
                 Some(!dont_check_game_version),
