@@ -1,6 +1,9 @@
+pub mod add;
 pub mod list;
 pub mod profile;
 mod remove;
 mod switch;
+mod upgrade;
 pub use remove::remove;
 pub use switch::switch;
+pub use upgrade::upgrade;
